@@ -161,7 +161,8 @@ class View(utils.SubjectMixin):
         self._create_ui()
         self._bind_events()
         
-        self.text_tags = []
+        self.text_tags_links = []
+        self.text_tags_search = []
 
         #self._current_text = None
         #self.user_text.focus_set()
@@ -182,6 +183,11 @@ class View(utils.SubjectMixin):
         # the note will be created synchronously, so we can focus the text area already
         self.text_note.focus()
 
+    def cmd_select_all(self, evt=None):
+        self.text_note.tag_add("sel", "1.0", "end-1c")
+        # we don't want the text bind_class() handler for Ctrl-A to be fired.
+        return "break"
+
     def get_continuous_rendering(self):
         return self.continuous_rendering.get()
         
@@ -293,6 +299,8 @@ class View(utils.SubjectMixin):
         self.text_note.bind("<Escape>", lambda e: self.lb_notes.focus())
         # <Key>
         
+        self.text_note.bind("<Control-a>", self.cmd_select_all)
+
         self.root.after(self.config.housekeeping_interval_ms, self.handler_housekeeper)
 
     def _create_menu(self):
@@ -374,6 +382,11 @@ class View(utils.SubjectMixin):
         edit_menu.add_command(label="Paste", accelerator="Ctrl+V",
                               underline=0, command=self.cmd_paste)
 
+        edit_menu.add_command(label="Select All", accelerator="Ctrl+A",
+                              underline=7, command=self.cmd_select_all)
+        # FIXME: ctrl-a is usually bound to start-of-line. What's a
+        # better binding for select all then?
+
         edit_menu.add_separator()
         
         edit_menu.add_command(label="Find", accelerator="Ctrl+F",
@@ -619,10 +632,43 @@ class View(utils.SubjectMixin):
 
         else:
             webbrowser.open(link)
+            
+    def activate_search_string_highlights(self):
+        t = self.text_note
+        
+        # remove all existing tags
+        for tag in self.text_tags_search:
+            t.tag_remove(tag, '1.0', 'end')
+        
+        del self.text_tags_search[:]
+        
+        st = self.get_search_entry_text()
+        if not st:
+            return
+        
+        # take care of invalid regular expressions...
+        try:
+            pat = re.compile(st)
+        except re.error:
+            return
+        
+        for mo in pat.finditer(t.get('1.0', 'end')):
+
+            # start creating a new tkinter text tag
+            tag = 'search-%d' % (len(self.text_tags_search),)
+            t.tag_config(tag, background="yellow")
+
+            # mo.start(), mo.end() or mo.span() in one go
+            t.tag_add(tag, '1.0+%dc' % (mo.start(),), '1.0+%dc' %
+                    (mo.end(),))
+
+            # record the tag name so we can delete it later
+            self.text_tags_search.append(tag)
+            
+        
 
     def activate_links(self):
         """
-
         Also see this post on URL detection regular expressions:
         http://www.regexguru.com/2008/11/detecting-urls-in-a-block-of-text/
         (mine is slightly modified)
@@ -635,10 +681,10 @@ class View(utils.SubjectMixin):
         r"\b((https?|ftp|file)://[-A-Za-z0-9+&@#/%?=~_|!:,.;]*[A-Za-z0-9+&@#/%=~_|])|(\[\[[^][]*\]\])"
 
         # remove all existing tags
-        for tag in self.text_tags:
+        for tag in self.text_tags_links:
             t.tag_remove(tag, '1.0', 'end')
 
-        del self.text_tags[:]
+        del self.text_tags_links[:]
         
         for mo in re.finditer(pat,t.get('1.0', 'end')):
             # extract the link from the match object
@@ -650,7 +696,7 @@ class View(utils.SubjectMixin):
                 ul = 1
 
             # start creating a new tkinter text tag
-            tag = 'web-%d' % (len(self.text_tags),)
+            tag = 'web-%d' % (len(self.text_tags_links),)
             t.tag_config(tag, foreground="blue", underline=ul)
             # hovering should give us the finger (cursor) hehe
             t.tag_bind(tag, '<Enter>', 
@@ -666,7 +712,7 @@ class View(utils.SubjectMixin):
                     (mo.end(),))
 
             # record the tag name so we can delete it later
-            self.text_tags.append(tag)
+            self.text_tags_links.append(tag)
 
 
     def handler_text_change(self, evt):
@@ -675,6 +721,7 @@ class View(utils.SubjectMixin):
         # handler, so that the poor regexp doesn't have to do every
         # single keystroke.
         self.activate_links()
+        self.activate_search_string_highlights()
                 
     def observer_notes_list(self, notes_list_model, evt_type, evt):
         if evt_type == 'set:list':
